@@ -1,6 +1,6 @@
 package Term::ANSIColor::Concise;
 
-our $VERSION = "2.05";
+our $VERSION = "2.06";
 
 use v5.14;
 use warnings;
@@ -225,7 +225,7 @@ sub ansi_numbers {
 	}
     } continue {
 	if ($SPLIT_ANSI) {
-	    my $index = first { not ref $numbers[$_] } 0 .. $#numbers;
+	    my $index = first { not ref $numbers[$_] } keys @numbers;
 	    if (defined $index) {
 		my @sgr = splice @numbers, $index;
 		push @numbers, [ 'SGR', @sgr ];
@@ -263,7 +263,7 @@ my %csi_terminator = (
     VPR => 'e',  # Vertical Position Relative
     HVP => 'f',	 # Horizontal Vertical Position
     SGR => 'm',	 # Select Graphic Rendition
-    DSR => 'n',	 # Device Status Report (0 cursor position)
+    DSR => 'n',	 # Device Status Report (6 cursor position)
     SCP => 's',	 # Save Cursor Position
     RCP => 'u',	 # Restore Cursor Position
     );
@@ -355,7 +355,7 @@ sub cached_ansi_color {
 	push @result, $text;
     }
     croak "Wrong number of parameters." if @_;
-    join '', @result;
+    wantarray ? @result : join('', @result);
 }
 
 use Scalar::Util qw(blessed);
@@ -400,6 +400,8 @@ sub apply_color {
 __END__
 
 
+=encoding utf8
+
 =head1 NAME
 
 Term::ANSIColor::Concise - Produce ANSI terminal sequence by concise notation
@@ -426,7 +428,7 @@ Term::ANSIColor::Concise - Produce ANSI terminal sequence by concise notation
 
 =head1 VERSION
 
-Version 2.05
+Version 2.06
 
 
 =head1 DESCRIPTION
@@ -455,7 +457,7 @@ be produced.  See L</ENVIRONMENT> section.
 
 =over 4
 
-=item B<ansi_color>(I<spec>, I<text>)
+=item B<ansi_color>(I<spec>, I<text>, ...)
 
 Return colorized version of given text.  Produces 256 or 24bit colors
 depending on the setting.
@@ -469,15 +471,16 @@ are applied accumulatively. For example, if an underline instruction
 is given for a string of red text, both specifications will be in
 effect.
 
-Actually, I<spec> and I<text> pair can be repeated as many as
-possible.  It is same as calling the function multiple times with
-single pair and join results.
+The I<spec> and I<text> pairs can be repeated any number of times. In
+scalar context, the results by each pair are returned as a
+concatenated string. When used in an array context, results are
+returned in a list.
 
 =item B<ansi_color>([ I<spec1>, I<spec2>, ... ], I<text>)
 
 If I<spec> parameter is ARRAYREF, multiple I<spec>s can be specified
-at once.  This is not useful for color spec because they can be simply
-joined, but may be useful when mixed with L</FUNCTION SPEC>.
+at once.  This is not useful for a text color spec because they can be
+simply joined, but may be useful when mixed with L</FUNCTION SPEC>.
 
 =item B<ansi_color_24>(I<spec>, I<text>)
 
@@ -689,8 +692,8 @@ C<SCP> and C<RCP> CSI code.
 
 =head1 COLOR NAMES
 
-Color names listed in L<Graphics::ColorNames::X> module can be used.
-See L<https://en.wikipedia.org/wiki/X11_color_names>.
+Color names listed in L<Graphics::ColorNames::X> module can be used in
+the form of C<< <NAME> >>.
 
     aliceblue antiquewhite aqua aquamarine azure beige bisque black
     blanchedalmond blue blueviolet brown burlywood cadetblue
@@ -912,7 +915,7 @@ The following copyright notice applies to all the files provided in
 this distribution, including binary files, unless explicitly noted
 otherwise.
 
-Copyright 2015-2023 Kazumasa Utashiro
+Copyright ©︎ 2015-2024 Kazumasa Utashiro
 
 
 =head1 LICENSE
