@@ -1,9 +1,9 @@
-package Term::ANSIColor::Concise::Util;
+package #
+ToggleValue {
 
-use v5.14;
-use warnings;
+    use v5.14;
+    use warnings;
 
-package Term::ANSIColor::Concise::ToggleValue {
     sub new {
 	my $class = shift;
 	my $obj = bless {}, $class;
@@ -12,20 +12,24 @@ package Term::ANSIColor::Concise::ToggleValue {
 	$obj->{CURRENT} = $obj->{INIT} = $opt{init} // 0;
 	$obj;
     }
+
     sub toggle {
 	my $obj = shift;
 	my $prev = $obj->{CURRENT};
 	$obj->{CURRENT} ^= $obj->{VALUE};
 	$prev;
     }
+
     sub value {
 	my $obj = shift;
 	$obj->{CURRENT};
     }
+
     sub reset {
 	my $obj = shift;
 	$obj->{CURRENT} = $obj->{INIT};
     }
+
 }
 
 1;
